var appDashboard = angular.module('appDashboard', [
    'ngRoute',
    'enplug.sdk',
    'enplug.utils',
    'ngDialog'
]);

appDashboard.config(function ($routeProvider, $locationProvider, $httpProvider){
    'use strict';
    $locationProvider.html5Mode(false);

    $routeProvider.when('/', {
        templateUrl: 'templates/list.html',
        controller: 'ListAssetsController'
    }).when('/create', {
        templateUrl: 'templates/form.html',
        controller: 'StoreAssetsController'
    }).when('/edit/:assetId', {
        templateUrl: 'templates/form.html',
        controller: 'UpdateAssetsController'
    });
});

appDashboard.factory('AssetService', function ($enplugAccount, $enplugDashboard, $route){
    'use strict';
    var assetService = {
        getProxyUrl: function(){
            return 'https://hashtagtv.com.br/enplug-apps/' + APP_FOLDER;
        },
        getAvailableChannels: function(){
            return [
				{key:'Dolar comercial, Euro e Libra',    channel:1, url:'https://hashtagtv.com.br/enplug-apps/' + APP_FOLDER + '/php/index.php?c=1'},
				{key:'Bovespa, Japão, Londres e Nasdaq', channel:2, url:'https://hashtagtv.com.br/enplug-apps/' + APP_FOLDER + '/php/index.php?c=2'}
            ];
        },
        validate: function (asset){
            if (asset.Value.Name == ''){
                return 'O nome do grupo é obrigatório.';
            }

            if (asset.Value.FeedActiveChannels.length <= 0){
                return 'Selecione o canal para o grupo.';
            }
            
            if (asset.Value.loadingMsg == ''){
                return 'A mensagem de loading é obrigatória.';
            }

            return '';
        },
        persistAsset: function (asset){
            var errorMsg = assetService.validate(asset),
                options = {
                    initialTab: 'displays',
                    showSchedule: true,
                    scheduleOptions: {
                        showDuration: true
                    },
                    loadingMessage: 'Salvando...',
                    successMessage: 'Novo grupo salvo com sucesso!',
                    errorMessage: 'O novo grupo não foi salvo, tente novamente.',
                    showDeployDialog: true
                };

            if (errorMsg != ''){
                $enplugDashboard.errorIndicator(errorMsg);
                return;
            }

            if (asset.Id != null){
                options.loadingMessage = 'Atualizando...';
                options.successMessage = 'Grupo atualizado com sucesso!';
                options.errorMessage = 'O grupo não foi atualizado, tente novamente.';
                options.showDeployDialog = false;
            }

            if (asset.VenueIds.length <= 0){
                options.showDeployDialog = true;
            }

            return $enplugAccount.saveAsset(asset, options);
        },
        deleteAsset: function (asset){
            $enplugDashboard.openConfirm({
                title: 'Deletar grupo',
                text: 'Tem certeza de que deseja excluir o grupo <strong>"' + asset.Value.Name + '"</strong>?',
                cancelText: 'Cancelar',
                confirmText: 'Deletar',
                confirmClass: 'btn-danger'
            }).then(function(){
                $enplugAccount.deleteAsset(asset.Id).then(function (response){
                    $enplugDashboard.successIndicator('Grupo "' + asset.Value.Name + '" excluído com sucesso!');
                    $route.reload();
                }, function(){
                    $enplugDashboard.errorIndicator('Não foi possível excluir o grupo, tente novamente.');
                });
            });
        },
        deployAsset: function (asset){
            var options = {
                initialTab: 'displays',
                showSchedule: true,
                scheduleOptions: {
                    showDuration: true
                },
                loadingMessage: 'Aguarde...',
                successMessage: 'Instalação da aplicação "' + asset.Value.Name + '" concluída com sucesso!',
                errorMessage: 'Falha na instalação da aplicação, tente novamente.',
                showDeployDialog: true
            };

            $enplugAccount.saveAsset(asset, options).then(function (response){
                $route.reload();
            });
        },
        updateSelectedChannelsKeys: function (uolChannel, currentSelectedChannelKeys){
            var start = currentSelectedChannelKeys.indexOf(uolChannel.key);

            if (start < 0){
                currentSelectedChannelKeys.push(uolChannel.key);
            } else {
                currentSelectedChannelKeys.splice(start, 1);
            }
			
			return currentSelectedChannelKeys;
        },
        getSelectedChannelsObjects(currentSelectedChannelKeys){
            var available = assetService.getAvailableChannels(),
				selecteds = [];

            angular.forEach(available, function (item){
                var isActive = currentSelectedChannelKeys.indexOf(item.key);

                if (isActive > -1){
                    selecteds.push(item);
                }
            });

            return selecteds;
        }
    };

    return assetService;
});

appDashboard.controller('ListAssetsController', function($scope, $location, $enplugDashboard, $enplugAccount, AssetService){
    'use strict';
    $scope.assets = [];
    $enplugDashboard.setHeaderTitle('');

    $enplugAccount.getAssets().then(function (_assets){
        $scope.assets = _assets;

        if ($scope.assets.length > 0){
            $enplugDashboard.setHeaderButtons([
                {text:' Criar grupo', action:$scope.createAsset, class:'btn btn-primary ion-android-add-circle'}
            ]);
        } else {
            $enplugDashboard.setHeaderButtons([]);
        }

        $enplugDashboard.pageLoading(false);
    }, function(){
        $enplugDashboard.errorIndicator('Falha no carregamento dos grupos, tente novamente.');
    });
	
    $scope.createAsset = function(){
        $enplugDashboard.pageLoading(true);
        $location.path('/create');
    };

    $scope.editAsset = function (id){
        $enplugDashboard.pageLoading(true);
        $location.path('/edit/' + id);
    };

    $scope.deployAsset = function (asset){
        AssetService.deployAsset(asset);
    };

    $scope.deleteAsset = function (asset){
        AssetService.deleteAsset(asset);
    };
});

appDashboard.controller('StoreAssetsController', function($scope, $location, $enplugDashboard, $enplugAccount, AssetService, ngDialog, $http, $window, $rootScope){
    'use strict';
    var availableUolChannels = AssetService.getAvailableChannels();
    $scope.channelsInfoType1 = [];
    $scope.channelsInfoType2 = [];
    $scope.selectedChannelsKeys = [];
    $scope.asset = {
        Id: null,
        VenueIds: [],
        Duration:20,
        Value: {
            Name: '',
            AcceptedUseTerms: false,
            FeedActiveChannels: [],
            proxyURL: AssetService.getProxyUrl(),
            loadingMsg:'Carregando conteúdo...'
        }
    };

    angular.forEach(availableUolChannels, function (item){
		if(item.channel == 2){
            $scope.channelsInfoType2.push(item);
		}else{
			$scope.channelsInfoType1.push(item);
        }
    });
	
    $enplugDashboard.setHeaderTitle('Criar grupo');
    $enplugDashboard.setHeaderButtons([
        {text:' Meus grupos', action:listAssets, class: 'btn btn-default ion-android-list'},
        {text:' Salvar', action:saveAsset, class: 'btn btn-primary ion-checkmark'}
    ]);
    $enplugDashboard.pageLoading(false);

    $scope.updateSelectedChannelsKeys = function(uolChannel){
        $scope.selectedChannelsKeys = AssetService.updateSelectedChannelsKeys(uolChannel, $scope.selectedChannelsKeys);
    };

	$scope.showXmlContent = function(xmlUrl){
        if(!xmlUrl){
            $window.alert('O documento selecionado não está disponível no momento, tente novamente mais tarde.');
            return;
        }

        $enplugDashboard.pageLoading(true);
        ngDialog.closeAll();

        $http({
            method:'GET',
            url:xmlUrl + '&a=2'
        }).success(function(response, status, headers, config){
            if(response.error){
                $enplugDashboard.pageLoading(false);
                $window.alert(response.message);
                return;
            }

            var dialog = ngDialog.open({
                template:'templates/showXmlContent.html',
                trapFocus:false,
                data:[response.content]
            });

            $rootScope.$on('ngDialog.opened', function(e, $dialog){
                $enplugDashboard.pageLoading(false);
            });
        }).error(function(data, status, headers, config){
            $enplugDashboard.pageLoading(false);
            $window.alert('O servidor não respondeu, tente novamente.');
        });
    };

    function listAssets(){
        ngDialog.closeAll();
        $location.path('/');
        return;
    };

    function saveAsset(){
        ngDialog.closeAll();
        $scope.asset.Value.FeedActiveChannels = AssetService.getSelectedChannelsObjects($scope.selectedChannelsKeys);

        AssetService.persistAsset($scope.asset).then(function(response){
            $location.path('/');
        });
    };
});

appDashboard.controller('UpdateAssetsController', function ($scope, $location, $route, $routeParams, $enplugDashboard, $enplugAccount, AssetService, ngDialog, $http, $window, $rootScope){
    'use strict';
    if (typeof $routeParams.assetId == 'undefined'){
        $enplugDashboard.errorIndicator('O grupo solicitado não existe, tente novamente.');
        $location.path('/');
        return;
    }

    var availableUolChannels = AssetService.getAvailableChannels();
    $scope.channelsInfoType1 = [];
    $scope.channelsInfoType2 = [];
    $scope.selectedChannelsKeys = [];
    $scope.asset = null;

    angular.forEach(availableUolChannels, function (item){
		if(item.channel == 2){
			$scope.channelsInfoType2.push(item);
		}else{
			$scope.channelsInfoType1.push(item);
		}
    });

    $enplugAccount.getAssets().then(function (_assets){
        if (_assets.length > 0){
            angular.forEach(_assets, function (item){
                if (item.Id == $routeParams.assetId){
                    $scope.asset = item;
                    return false;
                }
            });
        }

        if (!$scope.asset){
            $enplugDashboard.errorIndicator('O grupo solicitado não está mais disponível, tente novamente.');
            $location.path('/');
            return;
        }

        angular.forEach($scope.asset.Value.FeedActiveChannels, function (uolChannel){
            $scope.selectedChannelsKeys.push(uolChannel.key);
        });

        $enplugDashboard.setHeaderTitle('Editar grupo "' + $scope.asset.Value.Name + '"');
        $enplugDashboard.setHeaderButtons([
            {text:' Meus grupos', action:listAssets, class: 'btn btn-default ion-android-list'},
            {text:' Criar grupo',action:createAsset, class:'btn btn-default ion-android-add-circle'},
            {text:' Atualizar', action:updateAsset, class: 'btn btn-primary ion-checkmark'}
        ]);

        $enplugDashboard.pageLoading(false);
    }, function(){
        $enplugDashboard.errorIndicator('Não foi possível carregar o grupo selecionado, tente novamente.');
        $location.path('/');
    });
	
    $scope.updateSelectedChannelsKeys = function (uolChannel){
        $scope.selectedChannelsKeys = AssetService.updateSelectedChannelsKeys(uolChannel, $scope.selectedChannelsKeys);
    };

    $scope.showXmlContent = function(xmlUrl){
        if(!xmlUrl){
            $window.alert('O documento selecionado não está disponível no momento, tente novamente mais tarde.');
            return;
        }

        $enplugDashboard.pageLoading(true);
        ngDialog.closeAll();

        $http({
            method:'GET',
            url:xmlUrl + '&a=2'
        }).success(function(response, status, headers, config){
            if(response.error){
                $enplugDashboard.pageLoading(false);
                $window.alert(response.message);
                return;
            }

            var dialog = ngDialog.open({
                template:'templates/showXmlContent.html',
                trapFocus:false,
                data:[response.content]
            });

            $rootScope.$on('ngDialog.opened', function(e, $dialog){
                $enplugDashboard.pageLoading(false);
            });
        }).error(function(data, status, headers, config){
            $enplugDashboard.pageLoading(false);
            $window.alert('O servidor não respondeu, tente novamente mais tarde.');
        });
    };

    function listAssets(){
        ngDialog.closeAll();
        $location.path('/');
        return;
    };

    function createAsset(){
        ngDialog.closeAll();
        $enplugDashboard.pageLoading(true);
        $location.path('/create');
    };
    
    function updateAsset(){
        ngDialog.closeAll();
        $scope.asset.Value.FeedActiveChannels = AssetService.getSelectedChannelsObjects($scope.selectedChannelsKeys);
        $scope.asset.Value.proxyURL = AssetService.getProxyUrl();

        AssetService.persistAsset($scope.asset).then(function (response){
            $route.reload();
        });
    };
});