<?php
  header("Cache-Control: max-age=0, must-revalidate");
  header('Access-Control-Allow-Origin: *');
  header('Access-Control-Allow-Methods: GET');
  header('Content-type:application/json;charset=utf-8');

  // URL = https://admin.hashtagtv.com.br/enplug-apps/uol-financas/php/index.php?a=1&c=1,2
  ob_start("ob_gzhandler");

  if(ob_get_level() == 0){
    ob_start();
  }

  require_once __DIR__ . '/vendor/autoload.php';
  require_once '../shared.php';

	$availableActions = [1, 2];
	$action  = isset($_GET['a']) ? filter_var($_GET['a'], FILTER_SANITIZE_NUMBER_INT) : 0;
	$channels = [];

	if(isset($_GET['c'])){
		$chs = filter_var($_GET['c'], FILTER_SANITIZE_STRING);
    $chs = explode(',', $chs);

    if(count($chs) > 1){
      foreach($chs as $ch){
        $channels[] = $ch;
      }
    }else{
      $channels[] = $chs[0];
    }
  }

	if(!in_array($action, $availableActions)){
		$error = 'Mensagem: A ação solicitada ao serviço não é válida.' . PHP_EOL;
		$log = 'Arquivo: ' . __FILE__ . PHP_EOL;
		$log .= 'Linha: ' . __LINE__ . PHP_EOL;
		$log .= $error;
		$log .= 'action ID: ' . $action . PHP_EOL;
		$log .= '' . PHP_EOL;

		@file_put_contents('logs' . DIRECTORY_SEPARATOR . 'erro-uol-financas-' . date('Y-m-d') . '.log', $log, FILE_APPEND);

		echo json_encode([
			'error' => TRUE,
			'message' => $error
		]);
		
		exit();
	}
	
	if(empty($channels)){
		$error = 'Mensagem: Selecione no mínimo um "canal" e tente novamente.' . PHP_EOL;
		$log = 'Arquivo: ' . __FILE__ . PHP_EOL;
		$log .= 'Linha: ' . __LINE__ . PHP_EOL;
		$log .= $error;
		$log .= 'channel ID: ' . $channel . PHP_EOL;
		$log .= '' . PHP_EOL;

		@file_put_contents('logs' . DIRECTORY_SEPARATOR . 'erro-uol-financas-' . date('Y-m-d') . '.log', $log, FILE_APPEND);

		echo json_encode([
			'error' => TRUE,
			'message' => $error
		]);
		
		exit();
	}

	$response = getFeedContent([
		'action'  => $action,
		'channels' => $channels,
	]);
	
	echo json_encode($response);
	exit();
	
	function getFeedContent($params=[]){
		if($params['action'] == 2){
			$response = callUolService($params);
			
			if($response['error']){
				echo json_encode($response);
			}else{
				if(count($params['channels']) == 1){
					$response['content'] = $response['content'][$params['channels'][0]];
				}

				echo json_encode($response);
			}
			
			exit();
		}
		
		$jsonData = @file_get_contents('jsons/' . date('Y_m_d') . '/uol-financas-' . implode('-', $params['channels']) . '.json');
		
		if(!$jsonData){
			$jsonData = callUolService($params);
			
			if($jsonData['error']){
        return $jsonData;
      }
			
			$feed = $jsonData['content'];
		}else{
      $feed = json_decode($jsonData, TRUE);
    }

		$fonteUolEconomia = 'Fonte: UOL ECONOMIA';
		$html = '<div class="carousel-inner" role="listbox">';

		if(isset($feed[1]) && !empty($feed[1])){
			$html .= '<div class="item">';
			$html .= '<p class="top-right-title">Cotação</p>';
			$html .= '<div class="bottom-left-container">';
			$html .= '<img class="bg-bola-conteudo" src="' . getPlayerURL() . '/images/bg_bola_conteudo.png" />';
			$html .= '<div class="bottom-left-text-container">';

			foreach($feed[1] as $item){
				$dataHoraTxt = '';
				
				if(isset($item['dataHora']) && !empty($item['dataHora'])){
					$hora = explode(' ', $item['dataHora']);
					$hora = explode(':', $hora[1]);

					$dataHoraTxt = 'atualizado às ' . $hora[0] . 'h' . $hora[1];
				}
				
				$html .= '<div class="bottom-left-text-row' . $feed[1][0]['channel'] . '">';
				$html .= '<div class="pull-left bottom-left-column">';
				$html .= '<h1 class="bottom-left-column-title">' . $item['key'] . '</h1>';
				$html .= '<p class="bottom-left-column-variacao-venda">';
				$html .= 'Variação:&nbsp;&nbsp;' . number_format($item['variacao'], 4, ',', '.') . '%<br />';
				$html .= 'Venda:&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;R$' . number_format($item['venda'], 4, ',', '.');
				$html .= '</p>';

				if($item['variacao'] > 0){
					$html .= '<img class="bottom-left-column-icon" src="images/green-triangle.png" />';
				}else{
					$html .= '<img class="bottom-left-column-icon" src="images/red-triangle.png" />';
				}
				
				$html .= '</div>';
				$html .= '<div class="pull-right text-right bottom-left-right-column">';
				$html .= '<p class="bottom-left-right-column-compra">R$' . number_format($item['compra'], 4, ',', '.') . '</p>';
				$html .= '<p class="bottom-left-right-column-label-compra">Compra</p>';
				$html .= '<p class="bottom-left-right-column-horario">' . $dataHoraTxt . '</p>';
				$html .= '</div>';
				$html .= '</div>';
			}

			$html .= '<p class="bottom-left-author">' . $fonteUolEconomia . '</p>';
			$html .= '</div>';
			$html .= '</div>';
			$html .= '</div>';
		}
		
		if(isset($feed[2]) && !empty($feed[2])){
			$html .= '<div class="item">';
			$html .= '<p class="top-right-title top-right-title-bolsas">Bolsas</p>';
			$html .= '<div class="bottom-left-container">';
			$html .= '<img class="bg-bola-conteudo" src="images/bg_bola_conteudo.png" />';
			$html .= '<div class="bottom-left-text-container">';

			foreach($feed[2] as $item){
				$dataHoraTxt = '';
				
				if(isset($item['dataHora']) && !empty($item['dataHora'])){
					$hora = explode(' ', $item['dataHora']);
					$dataHoraTxt = 'atualizado ' . $hora[0];
					$hora = explode(':', $hora[1]);
					$dataHoraTxt .= ' às ' . $hora[0] . 'h' . $hora[1];
				}
				
				$html .= '<div class="bottom-left-text-row' . $feed[2][0]['channel'] . '">';
				$html .= '<h1 class="bottom-left-text-title">' . $item['key'] . '</h1>';
				$html .= '<div class="bottom-left-text-right-container">';
				
				if($item['variacao'] > 0){
					$html .= '<img class="bottom-left-text-icon" src="images/green-triangle.png" />';
				}else{
					$html .= '<img class="bottom-left-text-icon" src="images/red-triangle.png" />';
				}

				$html .= '<div class="pull-right text-right">';
				$html .= '<p class="bottom-left-porcentagem">';
				$html .= number_format($item['variacao'], 4, ',', '.');
				$html .= '%</p>';
				
				$html .= '<p class="bottom-left-porcentagem-atualizado">' . $dataHoraTxt . '</p>';
				$html .= '</div>';
				$html .= '</div>';
				$html .= '</div>';
			}

			$html .= '<p class="bottom-left-author">' . $fonteUolEconomia . '</p>';
			$html .= '</div>';
			$html .= '</div>';
			$html .= '</div>';
		}

		$html .= '</div>';

		return [
			'error' => FALSE,
			'content' => $html
		];
  }
	
	function callUolService($params=[]){
		$feed = json_decode(json_encode((array)simplexml_load_string(file_get_contents(getUolServiceUrl()), 'SimpleXMLElement', LIBXML_NOCDATA)), TRUE);

		if(!$feed || empty($feed)){
			$error = 'Mensagem: Falha na chamada ao service do UOL.' . PHP_EOL;
			$log = 'Arquivo: ' . __FILE__ . PHP_EOL;
			$log .= 'Linha: ' . __LINE__ . PHP_EOL;
			$log .= $error;
			$log .= 'feed: ' . $feed . PHP_EOL;
			$log .= '' . PHP_EOL;

			@file_put_contents('logs' . DIRECTORY_SEPARATOR . 'erro-uol-financas-' . $params['action'] . '.log'. $log, FILE_APPEND);

			return [
				'error' => TRUE,
				'message' => $error
			];
		}

		$jsonFolder = getJsonFolderPath();
		$content    = [];

		foreach($params['channels'] as $infoType){
			$channels = getUolFinancasChannels();

			if($infoType == 1){
				foreach($feed['cotacao'] as $item){
					if(!in_array($item['@attributes']['nome'], $channels[$infoType])){
						continue;
					}

					$row = [
						'channel'  => $infoType,
						'key'      => $item['@attributes']['nome'],
						'dataHora' => '',
					];
					
					if(isset($item['datahora']) && !empty($item['datahora'])){
						$row['dataHora'] = $item['datahora'];
					}

					$row['compra']   = str_ireplace(',', '.', str_ireplace('.', '', str_ireplace('%', '', $item['indice'][0])));
					$row['venda']    = str_ireplace(',', '.', str_ireplace('.', '', str_ireplace('%', '', $item['indice'][1])));
					$row['variacao'] = str_ireplace(',', '.', str_ireplace('.', '', str_ireplace('%', '', $item['indice'][2])));
					
					$content[$infoType][] = $row;
				}
				
				@file_put_contents($jsonFolder . DIRECTORY_SEPARATOR . 'uol-financas-1.json', json_encode([$infoType => $content[$infoType]]));
			}else{
				foreach($feed['cotacao'] as $item){
					if(!in_array($item['@attributes']['nome'], $channels[$infoType])){
						continue;
					}
					
					$row = [
						'channel'  => $infoType,
						'key'      => $item['@attributes']['nome'],
						'dataHora' => '',
						'pontos' => '',
					];
					
					if(isset($item['datahora']) && !empty($item['datahora'])){
						$row['dataHora'] = $item['datahora'];
					}

					if($row['key'] == 'Bovespa'){
						$row['variacao']      = str_ireplace(',', '.', str_ireplace('.', '', str_ireplace('%', '', $item['indice'][0])));
						$row['pontos'] = $item['indice'][1];
						$content[$infoType][] = $row;

						continue;
					}

					$row['variacao'] = str_ireplace(',', '.', str_ireplace('.', '', str_ireplace('%', '', $item['indice'])));

					$content[$infoType][] = $row;
				}
				
				@file_put_contents($jsonFolder . DIRECTORY_SEPARATOR . 'uol-financas-2.json', json_encode([$infoType => $content[$infoType]]));
			}
		}
		
		if(count($params['channels']) > 1){
			@file_put_contents($jsonFolder . DIRECTORY_SEPARATOR . 'uol-financas-1-2.json', json_encode([
				1 => $content[1],
				2 => $content[2],
			]));
		}

		return [
			'error' => FALSE,
			'content' => $content
		];
	}