<?php
  header("Cache-Control: max-age=0, must-revalidate");
  header('Access-Control-Allow-Origin: *');
  header('Access-Control-Allow-Methods: GET');
  header('Content-type:application/json;charset=utf-8');

  // URL = https://hashtagtv.com.br/enplug-apps/uol-financas-v2.0/php/index.php?a=1&c=1,2
  ob_start("ob_gzhandler");

  if(ob_get_level() == 0){
    ob_start();
  }

  require_once __DIR__ . '/vendor/autoload.php';
  require_once '../shared.php';

	$availableActions = [1, 2];
	$action  = isset($_GET['a']) ? filter_var($_GET['a'], FILTER_SANITIZE_NUMBER_INT) : 0;
	$channels = [];

	if(isset($_GET['c'])){
		$chs = filter_var($_GET['c'], FILTER_SANITIZE_STRING);
    $chs = explode(',', $chs);

    if(count($chs) > 1){
      foreach($chs as $ch){
        $channels[] = $ch;
      }
    }else{
      $channels[] = $chs[0];
    }
  }

	if(!in_array($action, $availableActions)){
		$error = 'Mensagem: A ação solicitada ao serviço não é válida.' . PHP_EOL;
		$log = 'Arquivo: ' . __FILE__ . PHP_EOL;
		$log .= 'Linha: ' . __LINE__ . PHP_EOL;
		$log .= $error;
		$log .= 'action ID: ' . $action . PHP_EOL;
		$log .= '' . PHP_EOL;

		@file_put_contents('logs' . DIRECTORY_SEPARATOR . 'erro-uol-financas-' . date('Y-m-d') . '.log', $log, FILE_APPEND);

		echo json_encode([
			'error' => TRUE,
			'message' => $error
		]);
		
		exit();
	}
	
	if(empty($channels)){
		$error = 'Mensagem: Selecione no mínimo um "canal" e tente novamente.' . PHP_EOL;
		$log = 'Arquivo: ' . __FILE__ . PHP_EOL;
		$log .= 'Linha: ' . __LINE__ . PHP_EOL;
		$log .= $error;
		$log .= 'channel ID: ' . $channel . PHP_EOL;
		$log .= '' . PHP_EOL;

		@file_put_contents('logs' . DIRECTORY_SEPARATOR . 'erro-uol-financas-vertical-' . date('Y-m-d') . '.log', $log, FILE_APPEND);

		echo json_encode([
			'error' => TRUE,
			'message' => $error
		]);
		
		exit();
	}

	$response = getFeedContent([
		'action'  => $action,
		'channels' => $channels,
	]);
	
	echo json_encode($response);
	exit();
	
	function getFeedContent($params=[]){
		if($params['action'] == 2){
			$response = callUolService($params);
			
			if($response['error']){
				echo json_encode($response);
			}else{
				if(count($params['channels']) == 1){
					$response['content'] = $response['content'][$params['channels'][0]];
				}

				echo json_encode($response);
			}
			
			exit();
		}
		
		$jsonData = @file_get_contents('jsons/' . date('Y_m_d') . '/uol-financas-v2.0-' . implode('-', $params['channels']) . '.json');
		
		if(!$jsonData){
			$jsonData = callUolService($params);
			
			if($jsonData['error']){
        return $jsonData;
      }
			
			$feed = $jsonData['content'];
		}else{
      $feed = json_decode($jsonData, TRUE);
    }

		$fonteUolEconomia = 'Fonte: UOL ECONOMIA';
		$html = '<div class="carousel-inner" role="listbox">';

		if(isset($feed[1]) && !empty($feed[1])){
			$html .= '<div class="item">';
			$html .= '<p class="top-right-title">UOL FINANÇAS</p>';
			$html .= '<div class="bottom-left-container">';
			$html .= '<img class="bg-bola-conteudo" src="' . getPlayerURL() . '/images/bg_bola_conteudo.png" />';
			$html .= '<div class="bottom-left-text-container">';

			foreach($feed[1] as $item){
				$dataHoraTxt = '';
				
				if(isset($item['dataHora']) && !empty($item['dataHora'])){
					$hora = explode(' ', $item['dataHora']);
					$hora = explode(':', $hora[1]);

					$dataHoraTxt = 'atualizado às ' . $hora[0] . 'h' . $hora[1];
				}
				
				$html .= '<div class="bottom-left-text-row' . $feed[1][0]['channel'] . '">';
				$html .= '<div class="pull-left bottom-left-column">';
				$html .= '<h1 class="bottom-left-column-title">' . $item['key'] . '</h1>';
				$html .= '<p class="bottom-left-column-variacao-venda">';
				$html .= 'Variação:&nbsp;&nbsp;' . number_format($item['variacao'], 4, ',', '.') . '%<br />';
				$html .= 'Venda:&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;R$' . number_format($item['venda'], 4, ',', '.');
				$html .= '</p>';

				if($item['variacao'] > 0){
					$html .= '<img class="bottom-left-column-icon" src="images/green-triangle.png" />';
				}else{
					$html .= '<img class="bottom-left-column-icon" src="images/red-triangle.png" />';
				}
				
				$html .= '</div>';
				$html .= '<div class="pull-right text-right bottom-left-right-column">';
				$html .= '<p class="bottom-left-right-column-compra">R$' . number_format($item['compra'], 4, ',', '.') . '</p>';
				$html .= '<p class="bottom-left-right-column-label-compra">Compra</p>';
				$html .= '<p class="bottom-left-right-column-horario">' . $dataHoraTxt . '</p>';
				$html .= '</div>';
				$html .= '</div>';
            }
            
            if(isset($feed[2]) && !empty($feed[2])){

                $item = $feed[2][0];
                
                $html .= '<br><hr><br>';

                $html .= '<div class="bottom-left-text-row' . $feed[2][0]['channel'] . '">';
                $html .= '<h1 class="bottom-left-text-title">' . $item['key'] . '</h1>';
                $html .= '<div class="bottom-left-text-right-container">';
                
                if($item['variacao'] > 0){
                    $html .= '<img class="bottom-left-text-icon" src="images/green-triangle.png" />';
                }else{
                    $html .= '<img class="bottom-left-text-icon" src="images/red-triangle.png" />';
                }
    
                $html .= '<div class="pull-right text-right">';
                $html .= '<p class="bottom-left-porcentagem">';
                $html .= number_format($item['variacao'], 4, ',', '.');
                $html .= '%</p>';
                
                $html .= '<p class="bottom-left-porcentagem-atualizado">' . $dataHoraTxt . '</p>';
                $html .= '</div>';
                $html .= '</div>';
                $html .= '</div>';  
            }

			$html .= '<p class="bottom-left-author">' . $fonteUolEconomia . '</p>';
			$html .= '</div>';
			$html .= '</div>';
			$html .= '</div>';
        }       
		
		$html .= '</div>';

		return [
			'error' => FALSE,
			'content' => $html
		];
  }
	
    function callUolService($params=[]) {
        $feed = json_decode(file_get_contents(getUolServiceUrl()));
        $feed2 = json_decode(file_get_contents(getUolExchangeServiceUrl()));

        if ((!$feed || empty($feed)) && (!$feed2 || empty($feed2))) {
            $error = 'Mensagem: Falha na chamada ao service do UOL.' . PHP_EOL;
            $log = 'Arquivo: ' . __FILE__ . PHP_EOL;
            $log .= 'Linha: ' . __LINE__ . PHP_EOL;
            $log .= $error;
            $log .= 'feed: ' . $feed . PHP_EOL;
            $log .= '' . PHP_EOL;

            @file_put_contents('logs' . DIRECTORY_SEPARATOR . 'erro-uol-financas-v2.0-' . $params['action'] . '.log'. $log, FILE_APPEND);

            return [
                'error' => TRUE,
                'message' => $error
            ];
        }

        $jsonFolder = getJsonFolderPath();
        $content = [];

        foreach ($params['channels'] as $infoType) {

            $channels = getUolFinancasChannels();

            if ($infoType == 1) {
                foreach ($feed->docs as $item) {

                    if (!in_array($item->name, $channels[$infoType])) {
                        continue;
                    }

                    $name = $item->name;
                    switch ($item->name) {
                        case "Dólar Comercial":
                            $name = "Dolar Comercial";
                            break;
                        case "Euro (R$)":
                            $name = "Euro";
                            break;
                        case "Libra Esterlina (R$)":
                            $name = "Libra";
                            break;
                    }

                    $row = [
                        'channel'  => $infoType,
                        'key'      => $name,
                        'dataHora' => '',
                    ];
                    
                    if(isset($item->date) && !empty($item->date)){
                        $dataHora = DateTime::createFromFormat('YmdHis', $item->date)->format('d/m/Y H:i');
                        $row['dataHora'] = $dataHora;
                    }

                    $row['compra'] = $item->bidvalue;
                    $row['venda'] = $item->askvalue;
                    $row['variacao'] = $item->variationpercentbid;
                    
                    $content[$infoType][] = $row;
                }
                
                @file_put_contents($jsonFolder . DIRECTORY_SEPARATOR . 'uol-financas-1.json', json_encode([$infoType => $content[$infoType]]));

            } else {

                foreach($feed2->docs as $item){

                    if (!in_array($item->exchangeasset, $channels[$infoType])) {
                        continue;
                    }
                    
                    $row = [
                        'channel'  => $infoType,
                        'key'      => ($item->exchangeasset == "BVSP BOVESPA IND" ? "Bovespa" : $item->exchangeasset),
                        'dataHora' => '',
                        'pontos' => '',
                    ];
                    
                    if(isset($item->date) && !empty($item->date)){
                        $dataHora = DateTime::createFromFormat('YmdHis', $item->date)->format('d/m/Y H:i');
                        $row['dataHora'] = $dataHora;
                    }

                    $row['variacao'] = $item->pctChange;
                    $row['pontos'] = $item->price;
                    $content[$infoType][] = $row;
                }
                
                @file_put_contents($jsonFolder . DIRECTORY_SEPARATOR . 'uol-financas-2.json', json_encode([$infoType => $content[$infoType]]));
            }
        }
        
        if(count($params['channels']) > 1){
            @file_put_contents($jsonFolder . DIRECTORY_SEPARATOR . 'uol-financas-1-2.json', json_encode([
                1 => $content[1],
                2 => $content[2],
            ]));
        }

        return [
            'error' => FALSE,
            'content' => $content
        ];
    }
